@@ -1672,8 +1672,8 @@ def cli(
                                         "User_ID",
                                         "Distance",
                                         "Longitude",
-                                        "Latitude"
-                                        "Retrieval_time"
+                                        "Latitude",
+                                        "Retrieval_time",
                                         ]
                                 )
                                 if hasattr(user, "peer"):
